/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.geoviewer;

import java.util.HashMap;
import java.util.Map;

/**
 * All presets are based on this BasePreset, so you could add layers from 
 * a preset, with refresh time and layer info if necessary. This BasePreset
 * also takes care of starting the correct timers for the dynamic layers.
 * 
 * @author Maarten Hollenga
 */
public abstract class BasePreset implements Preset {

    private Map<Layer, LayerInfo> layerInfoMap = new HashMap<Layer, LayerInfo>();

    protected void addLayer(Layer layer) {
        LayerInfo info = new LayerInfo(false, true, 0);
        addLayer(layer, info, 0);
    }

    protected void addLayer(Layer layer, LayerInfo layerInfo) {
        addLayer(layer, layerInfo, 0);
    }

    protected void addLayer(Layer layer, LayerInfo layerInfo, int refresh) {
        layerInfoMap.put(layer, layerInfo);
    }

    @Override
    public Map<Layer, LayerInfo> getLayerInfoMap() {
        return this.layerInfoMap;

    }


    /**
     * LayerData is used to hold a Layer and the matching LayerInfo.
     */
    class LayerData {

        Layer layer;
        LayerInfo layerInfo;

        public LayerData(Layer layer, LayerInfo layerInfo) {
            this.layer = layer;
            this.layerInfo = layerInfo;
        }
    }
}
