/**
 * Copyright (C) 2010 Cloudfarming <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package nl.cloudfarming.client.geoviewer;

import com.vividsolutions.jts.geom.Coordinate;
import java.util.Map;

/**
 * Interface for a preset. A preset consists of a bounding box and a set of 
 * layers to display in the map.
 * 
 * @author Timon Veenstra
 */
public interface Preset {

    /**
     * get the center piont for this preset
     *
     * 
     * @return WGS84 coordinates for the center piont of this preset
     */
    public Coordinate getCenterCoordinate();

    /**
     * get the default zoomlevel for this preset
     *
     * @return
     */
    public int getZoomLevel();

    /**
     * Gets the name of the preset.
     * 
     * @return Name of the preset
     */
    public String getName();

    /**
     * Gets the display name for the specified key.
     * 
     * @param key Key for the display name
     * @return Displayname
     */
    public String getKeyDisplayName(String key);


    Map<Layer, LayerInfo> getLayerInfoMap();


}
